<?php

namespace App\Controllers;

use App\Controllers\BaseController;

class AdminManager extends BaseController
{
    public function index()
    {
        $adminModel = model('Admin');
        $admins = $adminModel->findAll();
        $page_heading = "Admin Manager";
        $data = [
            'page_heading'    => $page_heading,
            'admins'          => $admins
        ];
        return view('manage-admins', $data);
    }

    public function manager()
    {
        $validationRules = [
            'action'    => 'required|string|max_length[50]',
            'id'        => 'required|integer',
        ];

        if (!$this->validate($validationRules)) {
            return redirect()->back()->with('failed', "Unable to delete! Invalid data.");
        }

        $validData = $this->validator->getValidated();
        $action = $validData['action'];
        $id     = $validData['id'];

        if ($id == 1) return redirect()->back()->with('failed', "Unable to delete");

        switch ($action) {
            case "delete";
                $adminModel = model('Admin');
                $admins = $adminModel->find($id);
                if ($admins) {
                    if ($adminModel->delete($id, true)) return redirect()->back()->with('success', "Admin Deleted Successfully");
                } else return redirect()->back()->with('failed', "Unable to delete");
                break;
            case "add":
                return $this->addAdmin();
                break;
            default:
                break;
        }
    }

    public function addAdmin()
    {
        $validationRules = [
            'name'                => 'required|string|max_length[100]',
            'email'               => 'required|string|valid_email|is_unique[admins.email]',
            'password'            => 'required|string|max_length[50]|min_length[10]',
            'confirm_password'    => 'required|string|max_length[50]|min_length[10]|matches[password]',
            'role'                => 'required|integer|max_length[10]',
        ];

        if (!$this->validate($validationRules)) {
            return redirect()->back()->withInput()->with('validation', $this->validator->getErrors());
        }

        $validData = $this->validator->getValidated();

        $validData['password'] = password_hash($validData['password'], PASSWORD_BCRYPT);

        $adminModel = model('Admin');

        if ($adminModel->insert($validData, false)) return redirect()->back()->with('success', "Admin added successfully.");
        else return redirect()->back()->withInput()->with('failed', "Unable to add admin please try again.");
    }

    public function editAdmin($id)
    {
        if($id == 1) return redirect()->back()->withInput()->with('failed', "Please try again.");
        $adminModel = model('Admin');

        $admin = $adminModel->find($id);
        if ($admin) {
            $page_heading = "Editing - " . $admin['name'];
            $data = [
                'page_heading'     => $page_heading,
                'admin'            => $admin,
            ];
            return view('edit-admin', $data);
        } else redirect()->back();
    }

    public function updateAdmin($id)
    {
        if($id == 1) return redirect()->back()->withInput()->with('failed', "Please try again.");
        
        $validationRules = [
            'name'                => 'required|string|max_length[100]',
            'role'                => 'required|integer|max_length[10]',
            'password'            => 'permit_empty|string|max_length[50]|min_length[10]',
            'confirm_password'    => 'permit_empty|string|max_length[50]|min_length[10]|matches[password]',
        ];

        if (!$this->validate($validationRules)) {
            return redirect()->back()->withInput()->with('validation', $this->validator->getErrors());
        }

        $validData = $this->validator->getValidated();

        if ($validData['name'] != "")       $user['name']       = $validData['name'];
        if ($validData['role'] != "")       $user['role']       = $validData['role'];
        if ($validData['password'] != "")   $user['password']   = password_hash($validData['password'], PASSWORD_BCRYPT);

        $adminModel = model('Admin');

        if ($adminModel->update($id, $user)) return redirect()->back()->withInput()->with('success', "Admin updated successfully.");
        else return redirect()->back()->withInput()->with('failed', "Unable to update admin please try again.");
    }
}
