<?php

namespace App\Controllers;

use App\Controllers\BaseController;
use CodeIgniter\RESTful\ResourceController;


class Auth extends BaseController
{
   
    public function index()
    {
                
        return view('login');
    }
    
    public function login()
    {
        $validationRules = [
            'email'    => 'required|max_length[254]|valid_email',
            'password' => 'required|max_length[50]|min_length[10]',
        ];
    
        if (!$this->validate($validationRules)) {
            $errors = $this->validator->getErrors();
    
            // Handle API request with JSON response
            if ($this->request->isAJAX()) {
                return $this->response->setJSON([
                    'status' => 'error',
                    'errors' => $errors
                ])->setStatusCode(400);
            }
    
            return redirect()->back()->withInput()->with('validationLogin', $errors);
        }
    
        $validData = $this->validator->getValidated();
    
        $session = session();
        $userModel = model('Admin');
    
        $email = $validData['email'];
        $password = $validData['password'];
    
        $userData = $userModel->where('email', $email)->first();
    
        if ($userData) {
            $hashedPassword = $userData['password'];
    
            if (password_verify($password, $hashedPassword)) {
    
                // Session-based login
                $session->set([
                    'uuid'        => $userData['id'],
                    'name'        => $userData['name'],
                    'email'       => $userData['email'],
                    'role'        => $userData['role'],
                    'isLoggedIn'  => true
                ]);
    
                // Handle API request with token response
                if ($this->request->isAJAX()) {
                    $token = bin2hex(random_bytes(32)); // Generate secure token
                    $userModel->update($userData['id'], ['token' => $token]);
    
                    return $this->response->setJSON([
                        'status'  => 'success',
                        'message' => 'Login successful',
                        'token'   => $token
                    ])->setStatusCode(200);
                }
    
                // Web-based login redirect
                return redirect()->to(site_url());
            } else {
                $error = ['password' => "Wrong password"];
    
                if ($this->request->isAJAX()) {
                    return $this->response->setJSON([
                        'status' => 'error',
                        'errors' => $error
                    ])->setStatusCode(401);
                }
    
                return redirect()->back()->withInput()->with('validationLogin', $error);
            }
        } else {
            $error = ['email' => "Invalid credentials."];
    
            if ($this->request->isAJAX()) {
                return $this->response->setJSON([
                    'status' => 'error',
                    'errors' => $error
                ])->setStatusCode(401);
            }
    
            return redirect()->back()->with('failed', "Invalid credentials.");
        }
    }
    

    public function createAccount()
    {
        $validationRules = [
            'email'    => 'required|max_length[254]|valid_email|is_unique[users.email]',
            'phone'    => 'required|regex_match[/^[6-9]{1}[0-9]{9}$/]|is_unique[users.phone]',
            'name'     => 'required|string|max_length[50]',
            'city'     => 'required|string|max_length[90]',
            'password' => 'required|max_length[50]|min_length[10]',
        ];

        if (!$this->validate($validationRules)) {
            return redirect()->back()->withInput()->with('validationReg', $this->validator->getErrors());
        }

        $validData = $this->validator->getValidated();

        $validData['password'] = password_hash($validData['password'], PASSWORD_BCRYPT);

        $userModel = model('Admin');

        $userModel->insert($validData);

        return redirect()->back()->with('success', "User Register Successfully.");
    }

    public function logout()
    {
        $session = session();
        $session->remove('isLoggedIn');
        $session->remove('uuid');
        $session->remove('name');
        $session->remove('email');
        $session->remove('role');
        $session->destroy();
        return redirect()->to(site_url());
    }
}
