<?php

namespace App\Controllers;

use App\Controllers\BaseController;
use CodeIgniter\HTTP\ResponseInterface;

class BannerManager extends BaseController
{
    public function index()
    {
        $bannerModel = model('Banner');
        $banners = $bannerModel->findAll();
        $page_heading = "Banner Manager";
        $data = [
            'page_heading'    => $page_heading,
            'banners'         => $banners
        ];
        return view('manage-banners', $data);
    }

    public function manager()
    {
        $validationRules = [
            'action'    => 'required|string|max_length[50]',
            'id'        => 'required|integer',
        ];

        if (!$this->validate($validationRules)) {
            return redirect()->back()->with('failed', "Unable to proceed! Invalid data.");
        }

        $validData = $this->validator->getValidated();
        $action = $validData['action'];
        $id     = $validData['id'];

        switch ($action) {
            case "delete";
                $bannerModel = model('Banner');
                $banners = $bannerModel->find($id);
                if ($banners) {
                    if ($bannerModel->delete($id, true)) return redirect()->back()->with('success', "Banner Deleted Successfully");
                } else return redirect()->back()->with('failed', "Unable to delete");
                break;
            case "add":
                return $this->addBanner();
                break;
            case "activate":
                $bannerModel = model('Banner');
                $banners = $bannerModel->find($id);
                if ($banners) {
                    $banner['status'] = 1;
                    if ($bannerModel->update($id, $banner)) return redirect()->back()->with('success', "Banner Activated Successfully");
                } else return redirect()->back()->with('failed', "Unable to activate");
                break;
            case "deactivate":
                $bannerModel = model('Banner');
                $banners = $bannerModel->find($id);
                if ($banners) {
                    $banner['status'] = 2;
                    if ($bannerModel->update($id, $banner)) return redirect()->back()->with('success', "Banner Deactivated Successfully");
                } else return redirect()->back()->with('failed', "Unable to deactivate");
                break;
            default:
                break;
        }
    }

    public function addBanner()
    {
        switch ($this->request->getMethod()) {
            case "GET":
                $bannerModel = model('Banner');

                $page_heading = "Add Banner";
                $data = [
                    'page_heading'     => $page_heading,
                ];
                return view('add-banner', $data);
                break;
            case "POST":
                $validationRules = [
                    'name'        => 'required|string|max_length[100]',
                    'type'        => 'required|integer|max_length[10]',
                    'location'    => 'required|integer|max_length[10]',
                    'content'     => 'required|string|max_length[1000]',
                ];

                if (!$this->validate($validationRules)) {
                    return redirect()->back()->withInput()->with('validation', $this->validator->getErrors());
                }

                $validData = $this->validator->getValidated();

                $bannerModel = model('Banner');

                if ($bannerModel->insert($validData, false)) return redirect()->back()->with('success', "Banner added successfully.");
                else return redirect()->back()->withInput()->with('failed', "Unable to add banner please try again.");
                break;
            default:
                break;
        }
        return;
    }

    public function editBanner($id)
    {
        $bannerModel = model('Banner');

        $banner = $bannerModel->find($id);
        if ($banner) {
            $page_heading = "Editing - " . $banner['name'];
            $data = [
                'page_heading'     => $page_heading,
                'banner'            => $banner,
            ];
            return view('edit-banner', $data);
        } else redirect()->back();
    }

    public function updateBanner($id)
    {

        $validationRules = [
            'name'        => 'required|string|max_length[100]',
            'type'        => 'required|integer|max_length[10]',
            'location'    => 'required|integer|max_length[10]',
            'content'     => 'required|string|max_length[1000]',
        ];

        if (!$this->validate($validationRules)) {
            return redirect()->back()->withInput()->with('validation', $this->validator->getErrors());
        }

        $validData = $this->validator->getValidated();

        $bannerModel = model('Banner');

        if ($bannerModel->update($id, $validData)) return redirect()->back()->withInput()->with('success', "Banner updated successfully.");
        else return redirect()->back()->withInput()->with('failed', "Unable to update banner please try again.");
    }
}
