<?php

namespace App\Controllers;

use CodeIgniter\I18n\Time;

class Dashboard extends BaseController
{
    public function index(): string
    {
        $auctionModel           = model('Auction');
        $userModel              = model('User');
        $contactUsDataModel     = model('ContactUsData');

     //   $users_count    = $userModel->countAll();
      //  $auction_count  = $auctionModel->countAll();
        // $leadCount      = $contactUsDataModel->countAll();

        $currentDateTime = Time::now()->format('Y-m-d');
        $logData = $this->readLogs($currentDateTime);
        $criticalCount  = substr_count($logData, 'CRITICAL -');
        $alertCount     = substr_count($logData, 'ALERT -');
        $emergencyCount = substr_count($logData, 'EMERGENCY -');
        $errorCount     = substr_count($logData, 'ERROR - ');
        $warningCount   = substr_count($logData, 'WARNING - ');

        $pattern = "/INFO - (.*?)--->>>pagelogend/";
        preg_match_all($pattern, $logData, $matches);
        $matches[1] = $this->getUserTraffic($matches[1]);

        $page_heading = "Dashboard";
        $data = [
            // 'auction_count'         => $auction_count,
            // 'users_count'           => $users_count,
            // 'leadCount'             => $leadCount,
            'errorCount'            => $criticalCount + $alertCount + $emergencyCount + $errorCount + $warningCount,
            'userTraffic'           => $matches[1],
            'page_heading'          => $page_heading
        ];
        return view('dashboard', $data);
    }

    protected function readLogs($date)
    {
        $logFile = WRITEPATH . 'logs/log-' . $date . '.log';

        if (file_exists($logFile)) {
            $logData = file_get_contents($logFile);
            return $logData;
        } else {
            return "Log file not found";
        }
    }

    protected function getUserTraffic($entries)
    {
        $hourlyCounts = [];
        foreach ($entries as $entry) {
            if (preg_match("/\b\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}\b/", $entry, $matches)) {
                $timestamp = $matches[0];
                $dateTime = new \DateTime($timestamp);
                $hour = $dateTime->format('Y-m-d H:00:00');
                $get = "Method -->> GET";
                $post = "Method -->> POST";

                if (!isset($hourlyCounts[$hour]['all'])) {
                    $hourlyCounts[$hour]['all'] = 1;
                    if (strpos($entry, $get) !== false) {
                        $hourlyCounts[$hour]['get'] = 1;
                        $hourlyCounts[$hour]['post'] = 0;
                    } elseif (strpos($entry, $post) !== false) {
                        $hourlyCounts[$hour]['post'] = 1;
                        $hourlyCounts[$hour]['get'] = 0;
                    }
                } else {
                    $hourlyCounts[$hour]['all']++;
                    if (strpos($entry, $get) !== false) {
                        $hourlyCounts[$hour]['get']++;
                    } elseif (strpos($entry, $post) !== false) {
                        $hourlyCounts[$hour]['post']++;
                    }
                }
            }
        }
        return $hourlyCounts;
    }
}
